@@ -1,12 +1,9 @@
 # coding: utf-8
 
-import logging
 import base64
 from flask import request, Response
 from oauthlib.common import to_unicode, bytes_type
 
-log = logging.getLogger('flask_oauthlib')
-
 
 def extract_params():
     """Extract request params."""
@@ -17,8 +14,6 @@ def extract_params():
         del headers['wsgi.input']
     if 'wsgi.errors' in headers:
         del headers['wsgi.errors']
-    if 'Http-Authorization' in headers:
-        headers['Authorization'] = headers['Http-Authorization']
 
     body = request.form.to_dict()
     return uri, http_method, body, headers
